% Style file for lecturenotes

% This version number is a Hg tip id
\ProvidesClass{lecturenotes}[2012/01/24, Hg:6665c4dd9fc4]

\newif\if@draft\@draftfalse
\DeclareOption{draft}{\@drafttrue}
\DeclareOption{final}{\@draftfalse}

\newif\if@psfonts\@psfontstrue
\DeclareOption{psfonts}{\@psfontstrue}
\DeclareOption{cmfonts}{\@psfontsfalse}

% Given that we're using PS fonts, should we use the mathtime or
% MTPro2 fonts, rather than just the mathptm ones (which aren't really ideal).
% It turns out that we can't test for the presence of the mathtime fonts
% from within this class file -- the only reliable way of checking if
% they're present is to look for something like rmtmi.pfa, but
% \IfFileExists isn't able to search for any of those files, only ones
% on the TEXINPUTS path such as mathtime.sty, which can be, and are
% often, installed without the fonts themselves being present.
\newcount\ln@mtselect \ln@mtselect=0
\DeclareOption{mathptm}{\@psfontstrue\ln@mtselect=0}
\DeclareOption{mathtime}{\@psfontstrue\ln@mtselect=1}
\DeclareOption{mtpro2}{\@psfontstrue\ln@mtselect=2}
% If \ifxetex is true, this is forced to \ln@mtselect=3

% No @-sign in this one, since it is written to a file which is read
% in later, when @ is other.
\newif\ifexampletext\exampletexttrue
\newif\ifexamplenotes\examplenotesfalse
\DeclareOption{examplenotes}{\examplenotestrue}
\DeclareOption{noexamplenotes}{\examplenotesfalse}

\newif\if@sidenotes\@sidenotesfalse
\DeclareOption{sidenotes}{\@sidenotestrue\examplenotestrue}
\DeclareOption{nosidenotes}{\@sidenotesfalse}

\newif\if@twosidepages\@twosidepagestrue
\DeclareOption{twoside}{\@twosidepagestrue}
\DeclareOption{oneside}{\@twosidepagesfalse}

\newif\if@screenpdf\@screenpdffalse
\DeclareOption{screenpdf}{\@screenpdftrue}

\def\@paperformat{a4paper}
\DeclareOption{a4paper}{\def\@paperformat{a4paper}}
\DeclareOption{letterpaper}{\def\@paperformat{letterpaper}}

\newif\if@hyperref\@hyperreftrue
\DeclareOption{hyperref}{\@hyperreftrue}
\DeclareOption{nohyperref}{\@hyperreffalse}

% Following doesn't work, for some reason.  They're not called when
% \usepackage{graphics} reads in graphics.cfg with its call to
% \ExecuteOption{...}.
%\newcount\LN@specialtype \LN@specialtype=0
%\DeclareOption{dvips}{\typeout{dvips option}\LN@specialtype=1}
%\DeclareOption{pdftex}{\typeout{pdftex option}\LN@specialtype=2}
%\DeclareOption{hpdftex}{\typeout{hpdftex option}\LN@specialtype=2}

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}

% Default options
\ExecuteOptions{final,cmfonts,nosidenotes,twoside}

% Hackily let a makefile (for example) add other \ExecuteOptions commands
\InputIfFileExists{lecturenotes.config}{}{}

\ProcessOptions

\PassOptionsToClass{\@paperformat}{article}

\if@screenpdf \@twosidepagesfalse \fi

% note: we have to do this this way, so that
% \PassOptionsToClass{*side}{article} is invoked only once --
% {article} gets confused if both options are passed to it
\if@twosidepages
  \PassOptionsToClass{twoside}{article}
\else
  \PassOptionsToClass{oneside}{article}
\fi

\LoadClass[fleqn]{article}

\RequirePackage{graphicx}
\RequirePackage{wrapfig}
\RequirePackage[english]{babel} % UK hyphenation
\RequirePackage[fleqn]{amsmath}
\RequirePackage{url}            % hyperref includes this by default

% Parameterise the parindent (used for a couple of things beyond parindent)
\newdimen\LN@parindent \LN@parindent=2em
\parindent\LN@parindent
% fleqn maths indent
\mathindent\parindent
% list left indentation
\leftmargini\parindent
\leftmarginii=0.5\parindent

% Check whether we're generating PDF.  Use the (now stable) ifpdf
% package, rather than rolling our own; also, this avoids conflicting
% with packages which import the ifpdf package themselves.
\RequirePackage{ifpdf}

% The following is basically just \RequirePackage{ifxetex},
% but also handling the case where ifxetex.sty isn't available
\IfFileExists{ifxetex.sty}
  {\RequirePackage{ifxetex}}
  {\newif\ifxetex \xetexfalse} % sensible default?

\ifxetex
  \pdftrue % ifpdf doesn't handle this case, and wrongly leaves \pdffalse
\fi

\ifpdf
  \if@hyperref
    \ifxetex
      % hyperref doesn't appear to detect this case automatically
      % (as of 2009/02/22 v6.78p)
      \usepackage[xetex]{hyperref}
    \else
      \usepackage{hyperref}
    \fi
    % hypertexnames=false is an undocumented hyperref switch which
    % makes hyperref generate unique link target names, even when (for
    % example) equation numbers are repeated.
    \hypersetup{hypertexnames=false}
  \else
    \def\pdfinfo#1{}% hyperref defines \pdfinfo, and we use it below
  \fi
%\else
%  \if@screenpdf
%    \ClassWarningNoLine{lecturenotes}{Can't have screenpdf if not generating PDF}
%    \@screenpdffalse
%  \fi
\fi
% Provide a default definition of \hypersetup (nothing happens if
% \hypersetup is already defined), so that we can use \hypersetup in
% documents without caring whether hyperref is being used or not.
\providecommand{\hypersetup}[1]{}

\if@screenpdf
  \ClassWarningNoLine{lecturenotes}{Generating screen PDF}
\fi

\def\RCS$#1: #2 ${\expandafter\def\csname RCS#1\endcsname{#2}}
% Output a special which will place a comment in the final output
% file.  We should create {dvips} and {pdftex} options to configure this.
% See message http://groups.google.com/groups?hl=en&selm=9fqgnv%2430d%241%40lenzie.cent.gla.ac.uk 
% The RCSInfo keyword in OutputFileCommentpdftex isn't one of the
% defined ones, but it doesn't seem to break anything.  Using
% pdfliteral to insert comments doesn't seem to work.
%
% OutputRcsIddvips must produce its output on two lines: if the line
% is too long then dvips breaks the comment line, which breaks the
% postscript (because of the 80-character line length limit).  We
% could do something exotic to measure the length of the line, but
% we'll just cross our fingers and hope.
{\catcode`\%=12
  \gdef\OutputRcsIddvips#1{\AtBeginDvi{\special{ps::% RCS Info:}\special{ps::%#1}}}}
\def\OutputRcsIdpdftex#1{\pdfinfo{/RCSInfo (#1)}}
%\ifcase\LN@specialtype		% 0 -- unknown
%  \ClassWarningNoLine{lecturenotes}{unspecified special type}
%  \let\RcsOutput\@gobble
%\or				% 1 -- dvips
%  \let\RcsOutput\OutputRcsIddvips
%\or				% 2 -- pdftex
%  \let\RcsOutput\OutputRcsIdpdftex
%\else
%  \ClassWarningNoLine{lecturenotes}{unrecognised special type}
%  \let\RcsOutput\@gobble
%\fi
\ifpdf
  \let\RCSINFO\OutputRcsIdpdftex
\else
  \let\RCSINFO\OutputRcsIddvips
\fi
\@onlypreamble\RCSINFO
% The hyperref package unconditionally adds \pdfinfo for Author and
% Title, so if we try to add these ourself (and if we're using
% hyperref), we get duplicate definitions which confuse PDF readers.
% Instead, use hyperref internals to set \@pdftitle and \@pdfauthor
\def\@SetDocumentInfo{%
  \ifx\@shorttitle\@empty \shorttitle{\@title}\fi
  \ifpdf
    \if@hyperref
      \pdfstringdef\@pdftitle{\@shorttitle}%
    \else
      \pdfinfo{/Title(\@shorttitle\ifx\@docident\@empty\ifx\RCSRevision\undefined\else\space[Revision \RCSRevision]\fi\else\space[\@docident]\fi)}%
    \fi
    \ifx\@author\@empty     \else
      \if@hyperref
        \pdfstringdef\@pdfauthor{\@author}%
      \else
        % Define to null any \\ and \thanks in the \author, to avoid
        % confusing \pdfinfo
        {\let\\\relax \let\thanks\@gobble \pdfinfo{/Author (\@author)}}%
      \fi
    \fi
  \fi
}
\AtBeginDocument{\@SetDocumentInfo}

% SubjectMetadata is an abstract which is to go into metadata.
% This is a brief note, with perhaps update/modification information,
% which in the case where I first added it was intended to go into
% a feed reader.
\def\SubjectMetadata#1{%
  \ifpdf
    \if@hyperref
      \pdfstringdef\@pdfsubject{#1}
    \else
      \pdfstringdef\@tempa{#1}
      \pdfinfo{/Subject (\@tempa)}
    \fi
  \fi
}

% Set the default extensions added to MetaPost input files
\ifpdf
  % generating .pdf
  \DeclareGraphicsExtensions{.pdf}
  \DeclareGraphicsRule{*}{mps}{*}{}
  % _Always_ use PS fonts if we're generating PDF
  \@psfontstrue
\else
  % generating .dvi
  \DeclareGraphicsRule{*}{eps}{*}{}
\fi


% Choose the font set, based on \if@psfonts and \ln@mtselect
\ifxetex
  \ifnum\ln@mtselect>0
    % set to non-default value
    \ClassWarning{lecturenotes}{Using XeTeX, so non-default font choices ignored}
  \fi
  \ln@mtselect=3
\fi
\if@psfonts
  \ifcase\ln@mtselect
    \RequirePackage{times,mathptm}
    \ClassWarningNoLine{lecturenotes}{Using mathptm fonts}
  \or
    \RequirePackage[LY1]{fontenc}	% specify text font encoding
    \RequirePackage[LY1,mtbold]{mathtime}	% switch math fonts
    \RequirePackage{times}	% switch text fonts (redundant)
    \ClassWarningNoLine{lecturenotes}{Using Mathtime fonts}
  \or
    \RequirePackage[T1]{fontenc} 
    \RequirePackage{textcomp} 
    \renewcommand{\rmdefault}{ptm} 
    \RequirePackage[scaled=0.92]{helvet} 
    % include \mathbb from mtpro2 (is this sensible?  What other
    % options should be added here?  Should I support adding options
    % from the document file, perhaps via \PassOptionsToClass?  Or is
    % this getting too complicated.
    \RequirePackage[mtpbb]{mtpro2}
  \or
    % XeTeX (how well does mathtime work with XeTeX (visually and
    % technically)?  For another time.
    \RequirePackage{fontspec} % For XeTeX
    \setmainfont{Optima}
    \setsansfont{Optima} % for headings?
    \setmonofont[Scale=0.8]{Monaco}
  \else
    \ClassError{lecturenotes}{Impossible value of mtselect: \ln@mtselect}
  \fi
\else
  \ClassWarningNoLine{lecturenotes}{Using CM fonts}
\fi

% Use the manfnt font, which includes the TeXBook dangerous-bend
% symbol (used in the {details} environment).  The following code comes
% from the manfnt package, by Denis Kosygin.
\DeclareFontFamily{U}{manual}{}
\DeclareFontShape{U}{manual}{m}{n}{ <-> manfnt }{}
\newcommand{\manfntsymbol}[1]{%
  {\fontencoding{U}\fontfamily{manual}\selectfont\symbol{#1}}}
\newcommand{\dangerousbend}{\manfntsymbol{127}}		% used in {details}
\newcommand{\righttriangle}{\manfntsymbol{'170}}	% used in {sidenote}
\newcommand{\text@dbend}[1]{%
  \settoheight{\@tempdima}{#1}%
  \divide\@tempdima by 15%
  \multiply\@tempdima by 22%
  \raisebox{\@tempdima}{#1}}
\newcommand{\textdangerousbend}{\text@dbend\dangerousbend}

% part numbering
\def\@partnumber{???}
\def\partnumber{%
	\pagenumbering{pagepart}
	\renewcommand \theequation {\@partnumber.\@arabic\c@equation}%
	\renewcommand \theexample {\@partnumber.\@arabic\c@example}%
	\gdef\@partnumber}
%
% Include partnumber in page numbers and equations
\def\@pagepart#1{\@partnumber-\number #1}
% Modify definition of \theequation from article.cls
% No... don't do this.  Let \partnumber redefine \theequation, so that 
% \theequation is left with its default value in the case where
% \partnumber is not invoked.
%\renewcommand \theequation {\@partnumber.\@arabic\c@equation}

% Short title, used in headings
\def\@shorttitle{}
\def\shorttitle#1{{\def\\{, }\xdef\@shorttitle{#1}}}

\def\@docident{}
\def\docident#1{\def\@docident{#1}}

% Set the ToC style
% Command \tocstyle{orig|plain|noleaders} sets the style, which is
% redefined AtBeginDocument time
\newcommand*\tocstyle@nonum@l@section[2]{%
    \ifnum \c@tocdepth >\z@
      \addpenalty\@secpenalty
      \addvspace{1.0em \@plus\p@}%
      \setlength\@tempdima{1.5em}%
      \begingroup
        \parindent \z@ \rightskip \@pnumwidth
        %\parfillskip -\@pnumwidth
        \leavevmode \bfseries
        \advance\leftskip\@tempdima
        \hskip -\leftskip
        #1 \nobreak\hfil \nobreak\par%\hb@xt@\@pnumwidth{\hss ##2}\par
      \endgroup
    \fi}
\def\tocstyle@orig{\typeout{Tocstyle orig}} %   Original article TOC style
\def\tocstyle@plain{%				Pared-down style
  \typeout{TOCstyle plain}
  % Hacky redifinition of table of contents definitions: no heading, no
  % page numbers, and no leaders.
  \renewcommand\tableofcontents{%
      \par
      \@starttoc{toc}%
      }
  \let\l@section\tocstyle@nonum@l@section
  \def\@dottedtocline##1##2##3##4##5{%
    \ifnum ##1>\c@tocdepth \else
      \vskip \z@ \@plus.2\p@
      {\leftskip ##2\relax \rightskip \@tocrmarg %\parfillskip -\rightskip
       \parindent ##2\relax\@afterindenttrue
       \interlinepenalty\@M
       \leavevmode
       \@tempdima ##3\relax
       \advance\leftskip \@tempdima \null\nobreak\hskip -\leftskip
       {##4}\nobreak
       \hfil
       \par}%
    \fi}
}
\def\tocstyle@noleaders{%			Simple ToC
  \typeout{TOCstyle noleaders}
  \let\l@section\tocstyle@nonum@l@section % do I want this?
  % Like orig, except without leaders, and
  % numbers closed up.  Bit ugly still (but I think better than leaders).
  \def\@dottedtocline##1##2##3##4##5{%
    \ifnum ##1>\c@tocdepth \else
      \vskip \z@ \@plus.2\p@
      {\leftskip ##2\relax \rightskip \@tocrmarg %\parfillskip -\rightskip
       \parindent ##2\relax\@afterindenttrue
       \interlinepenalty\@M
       \leavevmode
       \@tempdima ##3\relax
       \advance\leftskip \@tempdima \null\nobreak\hskip -\leftskip
       {##4}%
       %% I keep changing my mind about the best way to have these
       %% subsection page numbers -- none of the following are truly
       %% satisfactory.
       %\nobreak\quad|\space\emph{\small p##5}
       %,\nobreak\space\emph{\small p##5}
       \nobreak\space\raise 0.2ex\hbox{\tiny p##5}%
       \par}%
    \fi}
}
\def\tocstyle@sidebar{%
  % the main support for this is in \ps@titlepage below
  \tocstyle@noleaders % ...based on this style
  \typeout{TOCstyle sidebar}
  \usepackage{color}
  \definecolor{grey}{cmyk}{0.0,0.0,0.0,0.5}
}

\def\tocstyle#1{\def\tocstyle@SELECTED{#1}}
\tocstyle{plain}% my preferred default
\AtBeginDocument{\csname tocstyle@\tocstyle@SELECTED\endcsname}

% Override the article.cls {theindex} environment, to change
% \thispagestyle{plain} to {fancy}.  There appears to be some extra
% vertical space before the section title, which I can't track down.
\renewenvironment{theindex}
               {\if@twocolumn
                  \@restonecolfalse
                \else
                  \@restonecoltrue
                \fi
                \twocolumn[\section*{\indexname}]%
                \@mkboth{\MakeUppercase\indexname}%
                        {\MakeUppercase\indexname}%
                \thispagestyle{fancy}\parindent\z@
                \parskip\z@ \@plus .3\p@\relax
                \columnseprule \z@
                \columnsep 35\p@
                \let\item\@idxitem}
               {\if@restonecol\onecolumn\else\clearpage\fi}

% To include copyright and licence statements, call \CopyrightStatement
% and possibly also \LicenceStatement.  The former will be placed at
% the beginning of the document, and if the latter is defined, the
% pair will be placed at the end of the document.  The
% CopyrightStatement may or may not end in a full stop.
%
% The initialisations
% below must be \defs rather than \newcommands, since the latter makes
% them \long, which means they \ifx unequal to \@empty even when
% they're empty.
\def\@CopyrightStatement{}
\def\CopyrightStatement#1{\def\@CopyrightStatement{#1}}
\def\@LicenceStatement{}
%\long\def\LicenceStatement#1{\long\def\@LicenceStatement{#1}}
\def\LicenceStatement{\long\def\@LicenceStatement}
\def\@printLicence{%
  \ifx\@LicenceStatement\@empty\else
    % If there's a \@LicenceStatement, we assume that
    % \@CopyrightStatement is non-null also.
    \vfill
    \small\noindent
    \@CopyrightStatement
    % If there was a full stop at the end of that, add a space; if
    % not, add a sentence-ending full stop.  If there was a full stop,
    % then the \spacefactor will be >= 2000.
    \ifnum\spacefactor<2000 . \else\space\fi
    \@LicenceStatement
    \par
  \fi}

% Register \@readexamples and \@printLicence to be executed last-thing.
\AtEndDocument{\@readexamples\@printLicence}


\iftrue
\message{Configuration:^^J}
\message{draft: \if@draft true\else false\fi^^J}
\message{psfonts: \if@psfonts true\else false\fi^^J}
\message{mathtime: \expandafter\ifcase\ln@mtselect no\or mathtime\or mtpro2\fi^^J}
\message{sidenotes: \if@sidenotes true\else false\fi^^J}
\message{examplenotes: \ifexamplenotes true\else false\fi^^J}
\message{twosidepages: \if@twosidepages true\else false\fi^^J}
\message{hyperref: \if@hyperref true\else false\fi^^J}
\message{screenpdf: \if@screenpdf true\else false\fi^^J}
\message{generating PDF: \ifpdf true\else false\fi^^J}
\message{Paper format: \@paperformat^^J}
\fi

%%% Layout

\newdimen\overallwidth

\baselineskip=12pt % this is the article.sty default, but make it explicit
\if@screenpdf
  \@twosidepagesfalse
  \paperwidth=150mm \paperheight=150mm
  \voffset=0pt \hoffset=0pt
  \overallwidth=130mm
  \setlength{\textwidth}{130mm}
  \setlength{\oddsidemargin}{10mm}	\advance\oddsidemargin by -1in
  %\setlength{\topmargin}{10mm}		\advance\topmargin by -1in
  \setlength{\topmargin}{-1in}
  \setlength{\headheight}{12mm}
  \setlength{\headsep}{8mm}
  \setlength{\topmargin}{-1in}
  \setlength{\textheight}{120mm}
\else
  \overallwidth=\paperwidth
    \multiply \overallwidth by 16
    \divide \overallwidth by 21  % results in 160mm, for A4 paper
  \textwidth=0.75\overallwidth   % results in 120mm
  \setlength{\oddsidemargin}{-0.4mm}
  \if@twosidepages
    \setlength{\evensidemargin}{40mm}
  \fi
  \setlength{\topmargin}{-0.4mm}
  % I seem, at some point, to have decided on 235mm as the ideal
  % height for A4 paper, and to have set this as a fraction 0.79125 of
  % the paperheight, which gives this desired value when the
  % paperheight is that for A4.  Setting it as a multiple
  % of \baselineskip means that we don't get ugly pages when the page
  % is solid text, without section breaks.  56*12pt is 235.96mm.
  \setlength{\textheight}{56\baselineskip}
\fi

% headings
\RequirePackage{fancyhdr}
\pagestyle{fancy}
\setlength{\headwidth}{\overallwidth}
\fancyhead{}
\fancyfoot{}
\if@screenpdf
  \renewcommand{\footrulewidth}{0pt}
\else
  \renewcommand{\footrulewidth}{0.4pt}
  \if@twosidepages
    \fancyfoot[or,el]{\thepage}
  \else
    \fancyfoot[R]{\thepage}
  \fi
\fi

% Pagestyle for titlepage.  Is the \docident alternative below better?
\def\ps@titlepage{\let\@mkboth\@gobbletwo
  \let\@oddhead\@empty
  %\def\@oddfoot{\reset@font\small [\@docident]\hfil}%
  \if@screenpdf
    \let\@oddfoot\@empty
  \else
    \def\@oddfoot{%
      \vbox to 0pt{\vss
        \def\@tempa{sidebar}
        \ifx\tocstyle@SELECTED\@tempa
          \moveright 1.05\textwidth\vbox to 0pt{\hsize=1.05\headwidth
            \advance\hsize -\textwidth
            \vss
            \color{grey}
            \fontsize{8pt}{10pt}\selectfont
            \setcounter{tocdepth}2
            \raggedright  \frenchspacing \spaceskip=0.333em \xspaceskip=0.5em
            \tableofcontents
          }
        \fi
        \ifx\@docident\@empty
          \ifx\@CopyrightStatement\@empty
	    \@empty
	  \else
	    \vbox{\hrule\hbox{\reset@font\small\strut\@CopyrightStatement}}%
	  \fi
        \else
	  \ifx\@CopyrightStatement\@empty
	    \vbox{\hrule\hbox{\reset@font\small\strut[\@docident]}}%
	  \else
	    \vbox{\hrule\hbox{\reset@font\small\strut\@CopyrightStatement\ [\@docident]}}%
	  \fi
        \fi
    }}%
  \fi
  \let\@evenhead\@empty
  \let\@evenfoot\@oddfoot
}

% Redeclare the \emph command to use slanted text rather than italic
\DeclareTextFontCommand{\emph}{\slshape}

% Make wrapfig figures line up with the outer margin
\if@screenpdf
  \wrapoverhang=0pt
\else
  \wrapoverhang=\overallwidth
  \advance \wrapoverhang by -\textwidth
  % ... plus a little bit
  \advance \wrapoverhang by 1cm
\fi

% Figures are generally in wrapfigure environments, so rather
% compressed, so avoid taking up too much space:
\renewcommand{\figurename}{Fig.}

% Maximum width of figures to be placed in the margin
\newdimen\maxwrapfigurewidth
\maxwrapfigurewidth=\wrapoverhang

% Redefine article.cls makecaption, to make the text smaller, and
% indent margins in the case of normal figures
\def\LN@captionformat{\small\slshape}
\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  \@tempdima=\hsize \advance\@tempdima -2\LN@parindent
  \sbox\@tempboxa{\LN@captionformat #1: #2}%
  \ifdim \wd\@tempboxa >\@tempdima
    \def\@tempa{wrapfigure}%
    \ifx\@currenvir\@tempa
      \raggedright              % narrow column -- set ragged right
    \else
      % normal figure -- bring margins in by \LN@parindent both sides
      \hsize=\@tempdima \advance\hsize\LN@parindent
      \leftskip=\LN@parindent
    \fi
    \LN@captionformat
    #1: #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}



% Manage figures.  If figures are smaller than \wrapoverhang, then use
% wrapfigure to display them (therefore they'll appear entirely in the
% margin); if larger, then use a figure with a [ht]
% placement.  Allows us to have figures with labels but no captions.
%
% Starred form has #2 giving desired width, not actual width
\newcommand{\smallfigure}{%
  \@ifstar{\@tempswatrue\@smallfigure}{\@tempswafalse\@smallfigure}}
\newcommand{\@smallfigure}[4]{%
    % #1=figure filename
    % #2=figure width
    % #3=caption (may be empty)
    % #4=label (may be empty)
    \def\@tempa{#3}
    \def\@tempb{#4}
    \ifx\@tempa\@empty
      \ifx\@tempb\@empty
	%\typeout{no caption or label}
	\@temptokena={}
      \else
	%\typeout{label but no caption}
	% Add a caption containing just the label, and adjust
	% \@makecaption so this doesn't look silly.
	\@temptokena={%
	  \renewcommand{\figurename}{Figure}
	  \def\@makecaption##1##2{%
	    \vskip\abovecaptionskip \LN@captionformat ##1##2\vskip\belowcaptionskip}%
	  \caption{\label{#4}}}
      \fi
    \else
      \ifx\@tempb\@empty
	%\typeout{caption but no label}
	\@temptokena={\caption{#3}}
      \else
	%\typeout{caption and label}
	\@temptokena={\caption{#3\label{#4}}}
      \fi
    \fi
%    \ifdim#2>\wrapoverhang
    \ifdim#2>\maxwrapfigurewidth
      % wide figures go in a {figure} environment
      \begin{figure}[ht]\centering
	\if@tempswa
          \includegraphics[width=#2]{#1}%
	\else
          \includegraphics{#1}%
	\fi
	\the\@temptokena
      \end{figure}
    \else
%      \ifdim#2>0.5\wrapoverhang
	% If the figure will fit in the margin, put it there.
	% The obvious {O}[#2]{#2} doesn't work, for some reason.
	\begin{wrapfigure}{O}{#2}%
	  \if@tempswa
	    \includegraphics[width=#2]{#1}%
	  \else
	    \includegraphics{#1}%
	  \fi
	  \the\@temptokena
	\end{wrapfigure}
%      \else
%	% but narrow figures just have text wrapped around them
%	\begin{wrapfigure}{O}[0pt]{#2}\includegraphics{#1}%
%		\the\@temptokena\end{wrapfigure}
%      \fi
    \fi
}

% Choose the bibliographystyle for all the lecturenotes
\newcommand{\notesbibstyle}{unsrt}

% Modify the maketitle
\renewcommand\maketitle{\par
  \begingroup
    \renewcommand\thefootnote{\@fnsymbol\c@footnote}%
    \def\@makefnmark{\rlap{\@textsuperscript{\normalfont\@thefnmark}}}%
    \long\def\@makefntext##1{\parindent 1em\noindent
            \hb@xt@1.8em{%
                \hss\@textsuperscript{\normalfont\@thefnmark}}##1}%
    \if@twocolumn
      \ifnum \col@number=\@ne
        \@maketitle
      \else
        \twocolumn[\@maketitle]%
      \fi
    \else
      \newpage
      \global\@topnum\z@   % Prevents figures from going at top of page.
      \@maketitle
    \fi
    %\thispagestyle{plain}
    \thispagestyle{titlepage}
    \@thanks
  \endgroup
  \if@screenpdf 
    \ifx\@docident\@empty \else 
      \vfill\hbox{\reset@font\small\strut[\@docident]}%
    \fi
    \newpage
  \fi
  \setcounter{footnote}{0}%
  \global\let\thanks\relax
  \global\let\maketitle\relax
  \global\let\@maketitle\relax
  \global\let\@thanks\@empty
  \global\let\@author\@empty
  \global\let\@date\@empty
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\and\relax
}
\def\@maketitle{%
  \newpage
  \null
  \vskip 2em%
\vbox{\hsize=\headwidth
  \begin{flushright}%
  \let \footnote \thanks
    {\sffamily \LARGE \@title \par}%
    \vskip 1.5em%
    {\sffamily \large
      %\lineskip .5em%
      \lineskip .5ex % sensible?
      \@author\par
      }
    \vskip 1em%
    {\sffamily \large \@date}%
  \end{flushright}}%
  \par
  \vskip 1.5em
  % Set the right-head based on the short title, if any.
  \ifx\@shorttitle\@empty \shorttitle{\@title} \fi
  \if@screenpdf
    \fancyhead[L]{\@shorttitle}%
    \fancyhead[R]{\rightmark}
  \else
    \if@twosidepages
      \fancyhead[or,el]{\@shorttitle}%
    \else
      \fancyhead[R]{\@shorttitle}%
    \fi
  \fi
  % \@docident alternative -- better?
  %\ifx\@docident\empty \else
  %  {\def\@makefntext##1{\noindent [Version ##1]}%
  %   \footnotetext{\@docident}}\fi
  %
  %
  % Format the abstract if \@abstract is non-empty.  The
  % \@makeabstract, containing wrapfigure, must be at the top-level of
  % grouping for some reason.  Also, we always get a wrapfig warning
  % `Stationary wrapfigure forced to float on input line...' -- don't
  % know why.
  \ifx\@abstract\@empty \else
    \aftergroup\@makeabstract
  \fi
}

\def\@abstract{}
\long\def\abstract#1{\def\@abstract{#1}}
\def\@makeabstract{
  \vbox to 0pt{}\nointerlineskip % try to nudge up -- doesn't work...
  \vskip -\intextsep % wrapfig parameter: space left above and below
  \@tempdima=\overallwidth
    \advance\@tempdima -\textwidth
  \begin{wrapfigure}{r}[0.5\width]{2\@tempdima}
    %\raggedright
    \parindent=1em
    \small
    \noindent \textbf{Abstract:}
    \@abstract
  \end{wrapfigure}
}

%% % (Alternate) Abstract environment -- should come immediately after
%% % the \maketitle.  Sets the abstract in an artfully thin column in the
%% % margin.  This requires that the abstract isn't too long.
%% \renewenvironment{abstract}
%%   {\setbox0=\vbox\bgroup
%%      \hsize=\overallwidth
%%        \advance\hsize -\textwidth
%%        \advance\hsize -0.5cm
%%      \raggedright
%%      \parindent=2em
%%      \small
%%   }{\par\egroup
%%     \vbox to 0pt{\hbox to \overallwidth{\hfil\box0}\vss}
%%     \nointerlineskip
%%   }

% Footnotes would spoil the appearance here.  The following is a
% rather inadequate alternative -- the user will just have to think
% of a different way of displaying this -- perhaps with \@CopyrightStatement?
\renewcommand{\thanks}[1]{\break\small\strut[#1]\strut\break}

% Define section marks, though they're currently only used when screenpdf
\def\sectionmark#1{\markright{\thesection{} -- #1}}
\def\subsectionmark#1{\markright{\thesubsection{} -- #1}}
\def\subsubsectionmark#1{\markright{\thesubsubsection{} -- #1}}

% Modify the sections by having them in san serif, and save the
% current section level in \LN@currsectionlevel, for later use in \example
\renewcommand\section{\def\LN@currsectionlevel{section}%
	\if@screenpdf \newpage \fi
	\@startsection {section}{1}{\z@}%
		{-3.5ex \@plus -1ex \@minus -.2ex}%
		{2.3ex \@plus.2ex}%
		{\sffamily\Large\bfseries}}
\renewcommand\subsection{\def\LN@currsectionlevel{subsection}%
	\if@screenpdf \newpage \fi
	\@startsection{subsection}{2}{\z@}%
		{-3.25ex\@plus -1ex \@minus -.2ex}%
		{1.5ex \@plus .2ex}%
		{\sffamily\large\bfseries}}
\renewcommand\subsubsection{\def\LN@currsectionlevel{subsubsection}%
	\@startsection{subsubsection}{3}{\z@}%
		{-3.25ex\@plus -1ex \@minus -.2ex}%
		{1.5ex \@plus .2ex}%
		{\sffamily\normalsize\bfseries}}
\renewcommand\paragraph{\def\LN@currsectionlevel{paragraph}%
	\@startsection{paragraph}{4}{\z@}%
		{3.25ex \@plus1ex \@minus.2ex}%
		{-1em}%
		{\sffamily\normalsize\bfseries}}
\renewcommand\subparagraph{\def\LN@currsectionlevel{subparagraph}%
	\@startsection{subparagraph}{5}{\parindent}%
		{3.25ex \@plus1ex \@minus .2ex}%
		{-1em}%
		{\sffamily\normalsize\bfseries}}

% \unnumberedsection is like the starred versions of the sectioning
% commands, except that it _does_ add TOC entries, and PDF links and
% all.  It does this by invoking the unstarred version of the
% sectioning command, after setting secnumdepth to zero, and altering
% the appropriate section mark command.
%
% Call with \unnumberedsection{<section-command>}{<title>}, eg
% \unnumberedsection{section}{My section}
\def\unnumberedsection#1#2{%
  \mathchardef\c@savedsecnumdepth\c@secnumdepth
  \global\c@secnumdepth\z@
  \expandafter\let\expandafter\ss@savedmarkcommand\csname #1mark\endcsname
  \expandafter\def\csname #1mark\endcsname##1{\markright{##1}}
  \csname #1\endcsname{#2}
  \expandafter\let\csname #1mark\endcsname\ss@savedmarkcommand
  \global\c@secnumdepth\c@savedsecnumdepth
}


%%% New environments...

%%% {sidenote} envionment -- parenthetical note, omitted in student version
%
\newenvironment{sidenote}{\@bsphack
    \if@sidenotes			% change margins, text size & parindent
	\par				% env implies new para (unless skipped)
	\goodbreak
	\medskip
	% The following will probably fail if the note crosses a page
	% boundary.  But since it's not printed in the handed-out
	% version of the notes, that doesn't matter much.  Perhaps it
	% could go in the \everypar, so that it would be reset for each
	% paragraph? 
	\ifodd\count0
	    \advance\leftskip \parindent
	    % set right margin wider, and allow it to be slightly ragged
	    \advance\rightskip\hsize plus 5em
	    \advance\rightskip-\overallwidth
	\else
	    \if@twosidepages
		\advance\leftskip -\evensidemargin
		\advance\rightskip 0pt plus 5em
	    \else	% duplicate above
		\advance\leftskip \parindent
		\advance\rightskip\hsize plus 5em
		\advance\rightskip-\overallwidth
	    \fi
	\fi
	\parindent=0pt 
	\everypar{\hangindent=3pc \hangafter=-2
	  \hbox to 0pt{\hskip-\hangindent \righttriangle \hfil}}%
	\small
    \else
	\setbox0\vbox\bgroup	% put env. contents into box 0
    \fi
    }{%
    \if@sidenotes
	\par\medskip		% end para and group
    \else
	\egroup			% finish box 0 and discard
    \fi
    \@esphack
    }


%%% {examples} environment -- problem/example, to be collected at the end
%
% \if@examples is a flag to tell us if we've seen any examples yet.
\newif\if@examples \@examplesfalse
\newwrite\@exampleaux
\@definecounter{example}
%
% Don't use \newenvironment.  Instead use the fact that \begin{env}
% turns into \begingroup\env .  This code is simplified from
% Eijkhout's comment.sty
%
% The \@bsphack...\@esphack pair doesn't seem to want to work, here
% (well, it does in horizontal, but not in vertical, mode).
%
% The {example} environment takes an optional argument, giving the
% number of dangerousbend symbols to attach to the example.  The
% default is zero (negative numbers are treated the same as zero,
% numbers larger than about 2 are probably silly, but will work).
%
% Unfortunately, because of the \@ifnextchar, and the fact that the
% contents of this environment are processed oddly, you can't have
% anything expandable immediately after the \begin{example}, unless
% you write \begin{example}[0] or \begin{example}\relax.
%
% The end of the environment must be \end{example} alone on a line
% (ie, no whitespace before or after).  The same is true for the
% beginning and end of the {examplenotes} environment.
%
\def\makeother#1{\catcode`#1=12 }
\def\example{\@bsphack\@ifnextchar[%]
	\@example{\@example[0]}}
% \@openexamples opens the examples file.  Nilpotent.
\def\@openexamples{%
	\if@examples \else
		\immediate\openout\@exampleaux\jobname.examples%
		\immediate\write\@exampleaux{\relax}%
		\global\@examplestrue
	\fi
}
\def\theexample{\@arabic\c@example}
\def\@example[#1]{%
	\@openexamples
	\refstepcounter{example}%
	% Read in contents line by line, with all catcodes `other'
	\let\do\makeother \dospecials %
	\makeother\^^L%
	\endlinechar`\^^M \catcode`\^^M=12 %
	\immediate\write\@exampleaux %
		{\string\begin{examplebody}%
			{\theexample}%
			{\csname the\LN@currsectionlevel\endcsname}%
			{#1}%
		}%
	\if@screenpdf %
		\marginpar{\small{\hyperlink{ex-\@arabic\c@example}{Ex.\theexample}}}%
	\else %
		\marginpar{\small{See example \theexample}}%
	\fi %
        \@tempswatrue
	\ProcessExampleLine %
}
%
% Define \EndExampleTest, with all catcodes other
{\escapechar=-1 \xdef\EndExampleTest{\string\\end\string\{example\string\}}}
{\escapechar=-1 \xdef\BeginNotesTest{\string\\begin\string\{examplenotes\string\}}}
{\escapechar=-1 \xdef\EndNotesTest{\string\\end\string\{examplenotes\string\}}}
% Write out the body of the {example}, carefully surrounding the
% content of the {examplenotes} environment with
% \ifexamplenotes...\fi.  Note this _requires_ that the beginning and 
% end of the {examplenotes} environment appear on lines by
% themselves.  Change the escape character so that we can write out
% \if..\fi without problems.
{\catcode`\^^M=12 \endlinechar=-1 \catcode`\|=0 |catcode`|\=12 %
 |gdef|ProcessExampleLine#1^^M{|def|test{#1}%
        |if@tempswa
          |immediate|write|@exampleaux{\ifexampletext}|@tempswafalse
        |fi
	|ifx|BeginNotesTest|test %
		|immediate|write|@exampleaux{\fi\ifexamplenotes}%
	|fi %
	|ifx|EndExampleTest|test %
		|edef|next{%
			|immediate|write|@exampleaux{\fi\end{examplebody}}%
			|@esphack %
			|endgroup %
			}%
	|else %
		|immediate|write|@exampleaux{#1}%
		|ifx|EndNotesTest|test %
			|immediate|write|@exampleaux{\fi\ifexampletext}%
		|fi %
		|let|next|ProcessExampleLine %
	|fi %
	|next}%
}

% Add text to the examples file
\long\def\addtoexamples#1{%
	\@openexamples
	{\@temptokena{#1}%
	 \immediate\write\@exampleaux{\the\@temptokena}}}

%%% \readexamples -- read in the examples
%
% Read in the collection of examples, if any, at the end of the
% document.  \@readexamples is given as argument to the \AtEndDocument
% macro.
%
% \readexamples allows us to read the examples on demand.  The starred
% form is intended to suppress a clearpage, but it isn't working
% correctly (it seems to generate an almost-blank page when it's near
% the bottom of the page), so make it an alias for \@readexamples instead.
%
%\def\readexamples{\@ifstar{}\clearpage \@readexamples}
%\long\def\readexamples#1{%
%  \long\def\@readexamplespreamble{#1}%
%  \@readexamples}
\let\readexamples\@readexamples
%\def\@readexamplespreamble{}
\def\@readexamples{%
    \if@examples
	\immediate\closeout\@exampleaux
	%\clearpage
	\unnumberedsection{section}{Examples}
	%\@readexamplespreamble
	\@input{\jobname.examples}%
	\@examplesfalse		% Just in case \@readexamples is called twice
    \fi}

% Format a single example: arguments are the example number, and the
% section it appeared in.  I'm not sure that the dangerousbend symbol
% is formatted particularly well....
\newenvironment{examplebody}[3]{%
    \def\LN@currexample{#1}%
    \def\@currentlabel{#1}%
    \subsection*{%
	\if@screenpdf\hypertarget{ex-#1}{Example #1}\else Example #1\fi
	\ (section #2)%
	\ifnum#3>0
	    \space
	    {\normalfont
		\@tempcnta=#3
		\loop \ifnum\@tempcnta>0 \kern1pt\textdangerousbend
		    \advance\@tempcnta by -1
		\repeat
	    }%
	\fi
    }
    % Reset equation numbers to use a fresh sequence within each
    % example and its answer.  This requires
    % \hypersetup{hypertexnames=false} (see above), when used with
    % hyperref, otherwise the reused equation numbers make hyperref give errors,
    % complaining about duplicate link targets (bits borrowed from subeqn.sty)
    \mathchardef\c@mainequation\c@equation
    \def\theequation{\roman{equation}}
    \global\c@equation\z@
  }{
    \global\c@equation\c@mainequation
  }

%%% {examplenotes} -- notes/answers contained within {example}
%
% {examplenotes} 
% It might be better to put all the examplenotes together at the end.  
% But that's not particularly easy.
%
% Nice and simple.
\newenvironment{examplenotes}{%
	\par
	\penalty-50		% good break
	\vskip\smallskipamount
        \subsubsection*{Notes}
        \begingroup
        \fontsize{8pt}{11pt}\selectfont \raggedright
	}{%
	\par
	\endgroup
	\global\@ignoretrue
    }

%%% {details} environment -- more detailed notes, typeset separately
%
% The {details} environment takes an optional argument, giving the
% number of dangerousbend symbols to attach to the enclosed
% paragraphs.  The default is 1: any number greater than one is
% equivalent to 2; any number less is equivalent to 1.
%
% Following loosely based on the \d@nger macro on manmac.tex
%   \def\d@nger{\medbreak\begingroup\clubpenalty=10000
%     \def\par{\endgraf\endgroup\medbreak} \noindent\hang\hangafter=-2
%     \hbox to0pt{\hskip-\hangindent\dbend\hfill}\ninepoint}
%
\def\details{\@ifnextchar[\@details{\@details[1]}}
\def\@details[#1]{
  \par
  \medskip
  \clubpenalty=10000
  \advance\leftskip\parindent \advance\textwidth-\parindent
  \parindent=0pt
  \everypar={\hangindent=3pc \hangafter=-2
    \hbox to 0pt{\hskip-\hangindent
	\dangerousbend
	\ifnum #1>1 \kern1pt \dangerousbend\fi
	\hfil}}%
  \small}
\def\enddetails{\par\medskip}

% Redefine the article.cls definition of the {quotation} environment
\renewenvironment{quotation}{
    \list{}{\listparindent \parindent%
	    %\itemindent    \listparindent
	    \leftmargin	   \parindent
	    \rightmargin   \leftmargin
	    \parsep        \z@ \@plus\p@}%
    \item\relax
    \noindent
    \ignorespaces
  }{
    \endlist
  }

% and redefine {thebibliography} to change the mark text, and the spacing
\renewenvironment{thebibliography}[1]
     {\unnumberedsection{section}{\refname}%
      \markright{\refname}%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            %\@openbib@code
	    \parsep \z@
	    \itemsep \smallskipamount
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m
      \raggedright }            % bibliographies generally need ranged-left setting
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}


% Statement environment for stating principles.
% Takes an argument with a `title'.
% Within this environment, \label{foo} makes an equation-like label,
% and allows you to refer to it.
\def\LN@statementlabel#1{%
  \refstepcounter{equation}%
  \LN@origlabel{#1}\relax
  % See TeXBook ex.14.30
  \unskip
  \nobreak\hfill\penalty50
  \hskip 2em\hbox{}\nobreak\hfill (\theequation)%
  \parfillskip=0pt \par
}
\newenvironment{statement}[1]{%
    % The following is "\let\LN@origlabel\label" done lazily, so that it
    % picks up any redefinition of \label done after this package by hyperref
    \expandafter\ifx\csname LN@origlabel\endcsname\relax \global\let\LN@origlabel\label\fi
    \begin{quotation}
    \raggedright
    \textsl{#1:}\hskip0.5em
    \let\label\LN@statementlabel
  }{%
    \end{quotation}
  }


%%% Abbreviations
%
% The abbreviations here are intended to be fairly generic -- more
% specific ones should be defined in a per-project style file.

\def\:#1#2{{\scriptstyle\frac{#1}{#2}}}	% small fractions: \:12

% book/article citation
\let\citetitle\textsl

% \Diffl ab is \frac{da}{db}
% \Diffl[2]ab is \frac{d2a}{db2}
% \Diffl*ab is da/db
% \Diffl*[2]ab is d2a/db2
% Same for Partial
\def\Diffl{\@ifstar\@Difflflat\@Diffl}
\def\Partial{\@ifstar\@Partialflat\@Partial}
\def\@Partial{\@ifnextchar[{\@@Diffl\partial}{\@@Diffl\partial[]}}
\def\@Partialflat{\@ifnextchar[{\@@Difflflat\partial}{\@@Difflflat\partial[]}}
\def\@Diffl{\@ifnextchar[{\@@Diffl\dd}{\@@Diffl\dd[]}}
\def\@Difflflat{\@ifnextchar[{\@@Difflflat\dd}{\@@Difflflat\dd[]}}
\def\@@Diffl#1[#2]#3#4{%
  \def\@tempa{#2}%
  \ifx\@tempa\empty
    \frac{#1#3}{#1#4}%
  \else
    \frac{{#1}^{#2}#3}{#1{#4}^{#2}}%
  \fi}
\def\@@Difflflat#1[#2]#3#4{%
  \def\@tempa{#2}%
  \ifx\@tempa\empty
    #1#3\!/\!#1#4%
  \else
    {#1}^{#2}#3\!/\!#1{#4}^{#2}%
  \fi}
%\def\Partial{\@ifstar\@Partialflat\@Partial}
%\def\@Partial{\@ifnextchar[{\@@Diffl\partial}{\@@Diffl\partial[]}}
%\def\@Partialflat{\@ifnextchar[{\@@Difflflat\partial}{\@@Difflflat\partial[]}}
%\def\@Diffl{\@ifnextchar[{\@@Diffl\dd}{\@@Diffl\dd[]}}
%\def\@Difflflat{\@ifnextchar[{\@@Difflflat\dd}{\@@Difflflat\dd[]}}
%\def\@@Diffl#1[#2]#3#4{\frac{#1^{#2}#3}{#1#4^{#2}}}
%\def\@@Difflflat#1[#2]#3#4{#1^{#2}#3/#1#4^{#2}}

% common format for figure references, etc.
%\def\figref#1{Fig.~\ref{f:#1}}
%\def\eqnref#1{Eqn.~(\ref{e:#1})}
%\def\secref#1{Sect.~\ref{s:#1}}
%
% Give fig, eqn and secref optional prefix to reference (for xr.sty above)
% Need to \usepackage{xr}\externaldocument[1-]{part1} to refer to eqns, etc,
% in part1 with \eqnref[1-]{something}
\def\figref{\@ifnextchar[\@figref{\@figref[]}}
\def\eqnref{\@ifnextchar[\@eqnref{\@eqnref[]}}
\def\secref{\@ifnextchar[\@secref{\@secref[]}}
\def\objref{\@ifnextchar[\@objref{\@objref[]}} % reference to objective
\def\exref{\@ifnextchar[\@exref{\@exref[]}} % reference to example
\def\@figref[#1]#2{Fig.~#1\ref{#1f:#2}}
\def\@eqnref[#1]#2{Eqn.~(\ref{#1e:#2})}	% Eqn numbers include part no.
\def\@secref[#1]#2{Sect.~#1\ref{#1s:#2}}
\def\@objref[#1]#2{Objective~#1\ref{#1o:#2}}
\def\@exref[#1]#2{Example~#1\ref{#1x:#2}}

\def\be#1{\begin{equation}\label{e:#1}}
\def\ee{\end{equation}}
% \ben is \be without the label
\def\ben{\begin{equation}}

% Physical units in \rm.  Unstarred version includes leading
% \thinspace.  Starred version doesn't, and is used when referring to
% the unit by itself (eg axis is $B/\units*T$), and is not qualifying
% a number
\def\units{\@ifstar{\let\un@tsspace\relax    \un@ts}%
                   {\let\un@tsspace\thinspace\un@ts}}
\newcommand{\un@ts}[1]{{\let~\thinspace\ifmmode \un@tsspace\mathrm{#1}\else
	\nobreak$\un@tsspace\mathrm{#1}$\fi}}

% Vectors and matrices
\ifcase\ln@mtselect
  % mathptm fonts
  %\def\vec#1{\mathbf{#1}} -- doesn't work with greek letters?
  \def\vec#1{\mbox{\boldmath $#1$}}
\or % mathtime (should this be the same for mathtime as for mtpro2?
  \let\vec\mathbf
\or % mtpro2
  \let\vec\mathbold
\fi
\def\Mat#1{\mathsf{#1}}		% Matrix

% exponent, identity and implication
\newcommand{\expof}[1]{{\mathrm e}^{#1}}
\newcommand{\I}{\mathrm i}
\newcommand{\Implies}{\Rightarrow}

% Differential
\newcommand{\dd}{\mathrm{d}}
\newcommand{\ddd}{\,\mathrm{d}}  % inside an integral, including thinspace

% greater/less-than-or-approx-equal
\newcommand{\gap}{\mathrel{\vcenter{\hbox{\ooalign{\raise 4.75pt
	\hbox{$>$}\crcr $\sim$}}}}}
\newcommand{\lap}{\mathrel{\vcenter{\hbox{\ooalign{\raise 4.75pt
	\hbox{$<$}\crcr $\sim$}}}}}
